---
name: Documentation improvement
about: Suggest improvement for this project's documentation
title: DOCS
labels: documentation
assignees: ''

---

**Is it corrected in the latest version (master branch)?**
Yes/no

Latest version of the docs: https://rocketry.readthedocs.io/en/latest/

**Location in the documentation you wish to improve**
Paste the URL, ie. https://rocketry.readthedocs.io/en/latest/tutorial/quick_start.html#installing

**Describe the problem**
Describe what is unclear, where is a typo or what should be changed.

**Suggestion for the fix**
Please explain the suggested fix.
